@@ -50,6 +50,10 @@
 #include <libgames-support/games-atk-utils.h>
 #endif
 
+#if GLIB_CHECK_VERSION (2, 25, 15)
+#include <libgames-support/games-settings.h>
+#endif
+
 #include "board-noclutter.h"
 
 #include "ar-card-theme.h"
@@ -96,6 +100,9 @@
 #define LEAVE_FULLSCREEN_BUTTON
 #endif
 
+#define AR_SETTINGS_PATH_PREFIX "/org/gnome/solitaire/"
+#define AR_SETTINGS_WINDOW_STATE_PATH AR_SETTINGS_PATH_PREFIX "window-state/"
+
 enum
 {
   ACTION_UNDO_MOVE,
@@ -823,8 +830,8 @@ debug_choose_seed_cb (GtkAction *action,
 }
 
 static void
-debug_tweak_cb (GtkAction *action,
-                AisleriotWindow *window)
+debug_tweak_style_cb (GtkAction *action,
+                      AisleriotWindow *window)
 {
   AisleriotWindowPrivate *priv = window->priv;
   GObject *object;
@@ -841,6 +848,24 @@ debug_tweak_cb (GtkAction *action,
   gtk_window_present (GTK_WINDOW (prop_editor));
 }
 
+static void
+debug_tweak_settings_cb (GtkAction *action,
+                         AisleriotWindow *window)
+{
+  GObject *object;
+  GType type;
+  GtkWidget *prop_editor;
+
+  object = G_OBJECT (gtk_widget_get_settings (GTK_WIDGET (window)));
+  type = G_OBJECT_TYPE (object);
+
+  g_assert (object != NULL);
+
+  prop_editor = create_prop_editor (object, type);
+  gtk_window_set_transient_for (GTK_WINDOW (prop_editor), GTK_WINDOW (window));
+  gtk_window_present (GTK_WINDOW (prop_editor));
+}
+
 #endif /* ENABLE_DEBUG_UI */
 
 static void
@@ -1063,7 +1088,7 @@ apply_option (GtkToggleAction *action,
   active = gtk_toggle_action_get_active (action);
 
   action_name = gtk_action_get_name (GTK_ACTION (action));
-  value = g_ascii_strtoull (action_name + strlen ("Option"), NULL, 16);
+  value = g_ascii_strtoull (action_name + strlen ("Option"), NULL, 10);
 
   /* g_print ("option %s changed, value=%x set=%d\n", action_name, value, active); */
 
@@ -1306,7 +1331,7 @@ install_recently_played_menu (AisleriotWindow *window)
     char actionname[32];
     char *game_name, *tooltip;
 
-    g_snprintf (actionname, sizeof (actionname), "Recent%d", i);
+    g_snprintf (actionname, sizeof (actionname), "Recent%"G_GSIZE_FORMAT, i);
     game_name = games_filename_to_display_name (recent_games[i]);
 #ifdef HAVE_HILDON
     tooltip = NULL;
@@ -1786,9 +1811,8 @@ game_exception_response_cb (GtkWidget *dialog,
     char pidstr[64];
     const char * const argv[] = {
       "bug-buddy",
-      "--package", "gnome-games",
-      "--package-ver", VERSION,
-      "--appname", "aisleriot",
+      "--package", "aisleriot",
+      "--appname", "sol",
       "--pid", pidstr,
       "--include", (const char *) error_file,
 #if GLIB_CHECK_VERSION (2, 20, 0)
@@ -1803,7 +1827,11 @@ game_exception_response_cb (GtkWidget *dialog,
 
     g_snprintf (pidstr, sizeof (pidstr), "%d", getpid ());
 
+#if GTK_CHECK_VERSION (2, 91, 8)
+    if (!g_spawn_async (
+#else
     if (!gdk_spawn_on_screen (gtk_widget_get_screen (GTK_WIDGET (window)),
+#endif
                               NULL /* working dir */,
                               (char **) argv,
                               NULL /* envp */,
@@ -2030,11 +2058,13 @@ aisleriot_window_state_event (GtkWidget *widget,
     set_fullscreen_button_active (window);
 
 #ifndef HAVE_HILDON
+#if !GTK_CHECK_VERSION (2, 91, 0)
 #if GTK_CHECK_VERSION (2, 11, 0)
     gtk_statusbar_set_has_resize_grip (priv->statusbar, !is_maximised && !is_fullscreen);
 #else
     gtk_statusbar_set_has_resize_grip (priv->statusbar, FALSE);
 #endif
+#endif /* GTK < 3.0 */
 #endif /* !HAVE_HILDON */
   }
 
@@ -2168,7 +2198,9 @@ aisleriot_window_init (AisleriotWindow *window)
       G_CALLBACK (debug_game_prev) },
 #endif /* !HAVE_HILDON */
     { "DebugTweakStyle", NULL, "_Tweak Style", NULL, NULL,
-      G_CALLBACK (debug_tweak_cb) },
+      G_CALLBACK (debug_tweak_style_cb) },
+    { "DebugTweakSettings", NULL, "_Tweak GtkSettings", NULL, NULL,
+      G_CALLBACK (debug_tweak_settings_cb) },
 #endif /* ENABLE_DEBUG_UI */
 
     /* Accel actions */
@@ -2262,7 +2294,8 @@ aisleriot_window_init (AisleriotWindow *window)
         "<menu action='DebugMenu'>"
           "<menuitem action='DebugChooseSeed'/>"
           "<menuitem action='DebugTweakStyle'/>"
-        "</menu>"
+          "<menuitem action='DebugTweakSettings'/>"
+          "</menu>"
 #endif /* ENABLE_DEBUG_UI */
         "<menuitem action='CloseWindow'/>"
       "</popup>"
@@ -2310,6 +2343,7 @@ aisleriot_window_init (AisleriotWindow *window)
 #ifdef ENABLE_DEBUG_UI
         "<menu action='DebugMenu'>"
           "<menuitem action='DebugTweakStyle'/>"
+          "<menuitem action='DebugTweakSettings'/>"
           "<separator/>"
           "<menuitem action='DebugChooseSeed'/>"
           "<menuitem action='DebugMoveNextScreen'/>"
@@ -2431,11 +2465,15 @@ aisleriot_window_init (AisleriotWindow *window)
   g_signal_connect (priv->board, "status-message",
                     G_CALLBACK (board_status_message_cb), window);
 
+#if GTK_CHECK_VERSION (2, 91, 0)
+  gtk_window_set_has_resize_grip (GTK_WINDOW (window), TRUE);
+#else
 #if GTK_CHECK_VERSION (2, 11, 0)
   gtk_statusbar_set_has_resize_grip (priv->statusbar, TRUE);
 #else
   gtk_statusbar_set_has_resize_grip (priv->statusbar, FALSE);
 #endif
+#endif /* GTK 3.0 */
 
 #if GTK_CHECK_VERSION (2, 19, 1)
   statusbar_hbox = gtk_statusbar_get_message_area (statusbar);
@@ -2497,6 +2535,11 @@ aisleriot_window_init (AisleriotWindow *window)
   priv->main_menu = gtk_ui_manager_get_widget (priv->ui_manager, MAIN_MENU_UI_PATH);
   priv->toolbar = gtk_ui_manager_get_widget (priv->ui_manager, TOOLBAR_UI_PATH);
 
+#if GTK_CHECK_VERSION (3, 0, 3)
+  gtk_style_context_add_class (gtk_widget_get_style_context (priv->toolbar),
+                               GTK_STYLE_CLASS_PRIMARY_TOOLBAR);
+#endif
+
   /* Defer building the card themes menu until its parent's menu is opened */
 #ifdef HAVE_HILDON
   /* FIXMEchpe check this works! */
@@ -2624,7 +2667,11 @@ aisleriot_window_init (AisleriotWindow *window)
   gtk_window_set_default_size (GTK_WINDOW (window), MIN_WIDTH, MIN_HEIGHT);
 
   /* Restore window state */
+#if GLIB_CHECK_VERSION (2, 25, 15)
+  games_settings_bind_window_state (AR_SETTINGS_WINDOW_STATE_PATH, GTK_WINDOW (window));
+#else
   games_conf_add_window (GTK_WINDOW (window), NULL);
+#endif
 
   /* Initial focus is in the board */
   gtk_widget_grab_focus (GTK_WIDGET (priv->board));
